@@ -30,6 +30,10 @@ using namespace KLDAP;
 class KLdapTest : public QObject
 {
     Q_OBJECT
+public:
+    explicit KLdapTest(QObject *parent = nullptr);
+    ~KLdapTest() = default;
+
 private Q_SLOTS:
     //void testKLdap();
 
@@ -43,15 +47,13 @@ private Q_SLOTS:
     void testLdapDN();
     void testLdapModel();
 
-public Q_SLOTS:
+private:
     void searchResult(KLDAP::LdapSearch *search);
     void searchData(KLDAP::LdapSearch *search, const KLDAP::LdapObject &obj);
-
-private:
     QString m_url;
-    LdapSearch *m_search;
+    LdapSearch *m_search = nullptr;
     LdapObjects m_objects;
-    LdapModel *m_model;
+    LdapModel *m_model = nullptr;
 };
 
 #endif
