@@ -394,6 +394,7 @@ int LdapOperation::LdapOperationPrivate::processResult(int rescode, LDAPMessage
         char *name;
         struct berval **bvals;
         BerElement     *entry;
+        LdapAttrValue values;
 
         char *dn = ldap_get_dn(ld, msg);
         mObject.setDn(QString::fromUtf8(dn));
@@ -404,7 +405,6 @@ int LdapOperation::LdapOperationPrivate::processResult(int rescode, LDAPMessage
         while (name != nullptr) {
             // print the values
             bvals = ldap_get_values_len(ld, msg, name);
-            LdapAttrValue values;
             if (bvals) {
                 for (int i = 0; bvals[i] != nullptr; i++) {
                     char *val = bvals[i]->bv_val;
@@ -414,6 +414,7 @@ int LdapOperation::LdapOperationPrivate::processResult(int rescode, LDAPMessage
                 ldap_value_free_len(bvals);
             }
             attrs[ QString::fromLatin1(name) ] = values;
+            values.clear();
             ldap_memfree(name);
 
             // next attribute
@@ -639,12 +640,11 @@ static void createControls(LDAPControl ***pctrls, const LdapControls &ctrls)
 
 static void extractControls(LdapControls &ctrls, LDAPControl **pctrls)
 {
-    LDAPControl *ctrl;
     LdapControl control;
     int i = 0;
 
     while (pctrls[i]) {
-        ctrl = pctrls[ i ];
+        LDAPControl *ctrl = pctrls[ i ];
         control.setOid(QString::fromUtf8(ctrl->ldctl_oid));
         control.setValue(QByteArray(ctrl->ldctl_value.bv_val,
                                     ctrl->ldctl_value.bv_len));
@@ -1169,7 +1169,6 @@ int LdapOperation::waitForResult(int id, int msecs)
     LDAP *ld = (LDAP *) d->mConnection->handle();
 
     LDAPMessage *msg;
-    int rescode;
 
     QTime stopWatch;
     stopWatch.start();
@@ -1188,7 +1187,7 @@ int LdapOperation::waitForResult(int id, int msecs)
         tv.tv_usec = (timeout % 1000) * 1000;
 
         // Wait for a result
-        rescode = ldap_result(ld, id, 0, timeout < 0 ? nullptr : &tv, &msg);
+        int rescode = ldap_result(ld, id, 0, timeout < 0 ? nullptr : &tv, &msg);
         if (rescode == -1) {
             return -1;
         }
